; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, x
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, y
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, z
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, a
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, b
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DF, F, D, DF, F, c
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, x
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, y
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, z
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, a
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, b
time = 20
[Command]
name = "CrazyBuffy"
command = ~D, DB, B, D, DB, B, c
time = 20

[Command]
name = "Gigaton"
command = ~D, DF, F, D, DF, F, z+c
time = 20
[Command]
name = "Gigaton"
command = ~D, DB, B, D, DB, B, z+c
time = 20

;-| EX-Special Motions |------------------------------------------------------
[Command]
name = "QC_ex"
command = ~D, DF, F, x+y

[Command]
name = "QC_ex"
command = ~D, DF, F, y+z

[Command]
name = "QC_ex"
command = ~D, DF, F, z+x

[Command]
name = "QC_ex"
command = ~D, DB, B, x+y

[Command]
name = "QC_ex"
command = ~D, DB, B, y+z


[Command]
name = "QC_ex"
command = ~D, DB, B, z+x

[Command]
name = "QC_ax"
command = ~D, DF, F, a+b

[Command]
name = "QC_ax"
command = ~D, DF, F, b+c

[Command]
name = "QC_ax"
command = ~D, DF, F, c+a

[Command]
name = "QC_ax"
command = ~D, DB, B, a+b

[Command]
name = "QC_ax"
command = ~D, DB, B, b+c

[Command]
name = "QC_ax"
command = ~D, DB, B, c+a

[Command]
name = "upper_ex"
command = ~F, D, DF, x+y

[Command]
name = "upper_ex"
command = ~F, D, DF, y+z

[Command]
name = "upper_ex"
command = ~F, D, DF, z+x

[Command]
name = "upper_ex"
command = ~B, D, DB, x+y

[Command]
name = "upper_ex"
command = ~B, D, DB, y+z

[Command]
name = "upper_ex"
command = ~B, D, DB, z+x

[Command]
name = "upper_ax"
command = ~F, D, DF, a+b

[Command]
name = "upper_ax"
command = ~F, D, DF, b+c

[Command]
name = "upper_ax"
command = ~F, D, DF, c+a

[Command]
name = "upper_ax"
command = ~B, D, DB, a+b

[Command]
name = "upper_ax"
command = ~B, D, DB, b+c

[Command]
name = "upper_ax"
command = ~B, D, DB, c+a

[Command]
name = "CDU_ex"
command = ~20$D, $U, x+y
time = 10
[Command]
name = "CDU_ex"
command = ~20$D, $U, y+z
time = 10
[Command]
name = "CDU_ex"
command = ~20$D, $U, x+z
time = 10
[Command]
name = "CDU_ex"
command = ~20$D, $U, s
time = 10

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_z"
command = ~F, D, DF, z

[Command]
name = "upper_x"
command = ~B, D, DB, x

[Command]
name = "upper_y"
command = ~B, D, DB, y

[Command]
name = "upper_z"
command = ~B, D, DB, z

[Command]
name = "upper_a"
command = ~F, D, DF, a

[Command]
name = "upper_b"
command = ~F, D, DF, b

[Command]
name = "upper_c"
command = ~F, D, DF, c

[Command]
name = "upper_a"
command = ~B, D, DB, a

[Command]
name = "upper_b"
command = ~B, D, DB, b

[Command]
name = "upper_c"
command = ~B, D, DB, c

[Command]
name = "QC_x"
command = ~D, DF, F, x

[Command]
name = "QC_y"
command = ~D, DF, F, y

[Command]
name = "QC_z"
command = ~D, DF, F, z

[Command]
name = "QC_x"
command = ~D, DB, B, x

[Command]
name = "QC_y"
command = ~D, DB, B, y


[Command]
name = "QC_z"
command = ~D, DB, B, z

[Command]
name = "QC_a"
command = ~D, DF, F, a

[Command]
name = "QC_b"
command = ~D, DF, F, b

[Command]
name = "QC_c"
command = ~D, DF, F, c

[Command]
name = "QC_a"
command = ~D, DB, B, a

[Command]
name = "QC_b"
command = ~D, DB, B, b

[Command]
name = "QC_c"
command = ~D, DB, B, c


[Command]
name = "360_p"
command = ~$F, $D, $B, $U, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, x
time = 15
buffer.time = 3

[Command]
name = "360_p"
command = ~$F, $D, $B, $U, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, y
time = 15
buffer.time = 3

[Command]
name = "360_p"
command = ~$F, $D, $B, $U, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, z
time = 15
buffer.time = 3


[Command]
name = "CDU_x"
command = ~20$D, $U, x
time = 10
[Command]
name = "CDU_y"
command = ~20$D, $U, y
time = 10
[Command]
name = "CDU_z"
command = ~20$D, $U, z
time = 10

;-| N.Edge Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, ~x

[Command]
name = "upper_y"
command = ~F, D, DF, ~y

[Command]
name = "upper_z"
command = ~F, D, DF, ~z

[Command]
name = "upper_x"
command = ~B, D, DB, ~x

[Command]
name = "upper_y"
command = ~B, D, DB, ~y

[Command]
name = "upper_z"
command = ~B, D, DB, ~z

[Command]
name = "upper_a"
command = ~F, D, DF, ~a

[Command]
name = "upper_b"
command = ~F, D, DF, ~b

[Command]
name = "upper_c"
command = ~F, D, DF, ~c

[Command]
name = "upper_a"
command = ~B, D, DB, ~a

[Command]
name = "upper_b"
command = ~B, D, DB, ~b

[Command]
name = "upper_c"
command = ~B, D, DB, ~c

[Command]
name = "QC_x"
command = ~D, DF, F, ~x

[Command]
name = "QC_y"
command = ~D, DF, F, ~y

[Command]
name = "QC_z"
command = ~D, DF, F, ~z

[Command]
name = "QC_x"
command = ~D, DB, B, ~x

[Command]
name = "QC_y"
command = ~D, DB, B, ~y


[Command]
name = "QC_z"
command = ~D, DB, B, ~z

[Command]
name = "QC_a"
command = ~D, DF, F, ~a

[Command]
name = "QC_b"
command = ~D, DF, F, ~b

[Command]
name = "QC_c"
command = ~D, DF, F, ~c

[Command]
name = "QC_a"
command = ~D, DB, B, ~a

[Command]
name = "QC_b"
command = ~D, DB, B, ~b

[Command]
name = "QC_c"
command = ~D, DB, B, ~c

[Command]
name = "360_p"
command = ~$F, $D, $B, $U, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, ~x
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, ~x
time = 15
buffer.time = 3

[Command]
name = "360_p"
command = ~$F, $D, $B, $U, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, ~y
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, ~y
time = 15
buffer.time = 3

[Command]
name = "360_p"
command = ~$F, $D, $B, $U, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $B, $U, $F, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $U, $F, $D, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $F, $D, $B, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$B, $D, $F, $U, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$D, $F, $U, $B, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$F, $U, $B, $D, ~z
time = 15
buffer.time = 3
[Command]
name = "360_p"
command = ~$U, $B, $D, $F, ~z
time = 15
buffer.time = 3


[Command]
name = "CDU_x"
command = ~20$D, $U, ~x
time = 10
[Command]
name = "CDU_y"
command = ~20$D, $U, ~y
time = 10
[Command]
name = "CDU_z"
command = ~20$D, $U, ~z
time = 10


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "TapUp"     ;Required (do not remove)
command = $U

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10

;-| V-Single Button |---------------------------------------------------------
[Command]
name = "v1"
command = a
time = 1

[Command]
name = "v2"
command = b
time = 1

[Command]
name = "v3"
command = c
time = 1

[Command]
name = "v1"
command = x
time = 1

[Command]
name = "v2"
command = y
time = 1

[Command]
name = "v3"
command = z
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "vCrazyBuffy"
command = ~D, DF, F, D, DF, F, x
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "vupper1"
command = ~F, D, DF, x
[Command]
name = "vupper1"
command = ~F, D, DF, a
[Command]
name = "vupper2"
command = ~F, D, DF, y
[Command]
name = "vupper2"
command = ~F, D, DF, b
[Command]
name = "vupper3"
command = ~F, D, DF, z
[Command]
name = "vupper3"
command = ~F, D, DF, c

[Command]
name = "vrupper1"
command = ~B, D, DB, x
[Command]
name = "vrupper1"
command = ~B, D, DB, a
[Command]
name = "vrupper2"
command = ~B, D, DB, y
[Command]
name = "vrupper2"
command = ~B, D, DB, b
[Command]
name = "vrupper3"
command = ~B, D, DB, z
[Command]
name = "vrupper3"
command = ~B, D, DB, c

[Command]
name = "vQCF1"
command = ~D, DF, F, x
[Command]
name = "vQCF1"
command = ~D, DF, F, a
[Command]
name = "vQCF2"
command = ~D, DF, F, y
[Command]
name = "vQCF2"
command = ~D, DF, F, b
[Command]
name = "vQCF3"
command = ~D, DF, F, z
[Command]
name = "vQCF3"
command = ~D, DF, F, c

[Command]
name = "vQCB1"
command = ~D, DB, B, x
[Command]
name = "vQCB1"
command = ~D, DB, B, a
[Command]
name = "vQCB2"
command = ~D, DB, B, y
[Command]
name = "vQCB2"
command = ~D, DB, B, b
[Command]
name = "vQCB3"
command = ~D, DB, B, z
[Command]
name = "vQCB3"
command = ~D, DB, B, c

[Command]
name = "vCDU1"
command = ~20$D, $U, x
time = 10
[Command]
name = "vCDU2"
command = ~20$D, $U, y
time = 10
[Command]
name = "vCDU3"
command = ~20$D, $U, z
time = 10

[Command]
name = "vCDU1"
command = ~20$D, $U, a
time = 10
[Command]
name = "vCDU2"
command = ~20$D, $U, b
time = 10
[Command]
name = "vCDU3"
command = ~20$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

[Command]
name = "lplk"
command = x+a
time = 1

[Command]
name = "tupac"
command = x+a
time = 1
[Command]
name = "tupac"
command = y+b
time = 1
[Command]
name = "tupac"
command = z+c
time = 1

[Command]
name = "hphk"
command = z+c
time = 1

[Command]
name = "3Punch"
command = x+y+z
time = 1


;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = anim != 210
trigger2 = anim != 220
trigger2 = anim != 221
trigger2 = anim != 240
trigger2 = anim != 440
trigger2 = anim != 250
trigger2 = anim != 251
trigger2 = anim != 450
trigger2 = anim != 10210
trigger2 = anim != 10220
trigger2 = anim != 10221
trigger2 = time;movecontact
;trigger3 = stateno = 100
trigger3 = stateno = 40
trigger3 = animtime != 0
var(9) = 1


; AI-related stuff starts here

[State AI, RESET]
type = VarSet
trigger1 = fvar(35)=0
trigger2 = random >= (fvar(35)-8)*2
var(52) = 0
ignorehitpause = 1

; NORMAL AI

[State AI, Consider backing off]
type = VarSet
triggerall = roundstate = 2
triggerall = fvar(35)
triggerall = var(52) = 0 || random < 80+fvar(35)
triggerall = random < 200 + (123*(prevstateno = 440 && (p2stateno=[5070,5100]) ) )
triggerall = numenemy
triggerall = (p2stateno = [5110,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120))
triggerall = p2bodydist x <= 42
trigger1 = stateno != 40
trigger1 = ctrl || (stateno=[20,21])
var(52) = ifelse(backedgebodydist <= 60, 700, ifelse(random<500&&(helper(10003),var(30)|| fvar(35)<=4.0),105,705) )
ignorehitpause = 1

[State AI, Consider C.Z]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 25
triggerall = p2dist y >= -110 - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 7 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 420
trigger2 = stateno = 200
trigger2 = (moveguarded)
var(52) = 420
ignorehitpause = 1

[State AI, Consider C.X]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 30
triggerall = p2dist y >= -50 - (enemynear,vel y*2)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 2 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 400
trigger2 = prevstateno != 400
trigger2 = stateno = 400
trigger2 = (moveguarded)
var(52) = 400
ignorehitpause = 1

[State AI, Consider C.A]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 30
triggerall = p2dist y >= -20 - (enemynear,vel y*2)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 2 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 430
;trigger2 = stateno = 400
;trigger2 = (moveguarded)
var(52) = 430
ignorehitpause = 1

[State AI, Consider C.Y]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 35
triggerall = p2dist y >= -40 - (enemynear,vel y*4)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 410
trigger2 = stateno = 400
trigger2 = (moveguarded)
var(52) = 410
ignorehitpause = 1

[State AI, Consider C.B]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 35
triggerall = p2dist y >= -20 - (enemynear,vel y*5)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 5 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 440
trigger2 = stateno = 400
trigger2 = (moveguarded)
var(52) = 440
ignorehitpause = 1

[State AI, Consider S.Y]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 30
triggerall = p2dist y >= -100 - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 6 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 210
trigger2 = prevstateno != 210
trigger2 = stateno = 200 || stateno = 240
trigger2 = (movecontact)
var(52) = 210
ignorehitpause = 1

[State AI, Consider S.B]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 100)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 35
triggerall = p2dist y >= -40 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -35*const(size.yscale)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 5 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 240
trigger2 = (stateno = 200 && anim = 201)
trigger2 = (movecontact)
var(52) = 240
ignorehitpause = 1

[State AI, Consider S.X]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 40
triggerall = p2dist y >= -80 - (enemynear,vel y*3)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 3 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 200
trigger2 = prevstateno != 200
trigger2 = stateno = 200
trigger2 = (moveguarded)
var(52) = 200
ignorehitpause = 1

[State AI, Consider C.C]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5180]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 50
triggerall = p2dist y >= -20 - (enemynear,vel y*8)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 450
trigger2 = stateno = 200 || stateno = 400
trigger2 = (moveguarded)
var(52) = 450
ignorehitpause = 1

[State AI, Consider S.A]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,-8),60-(4*movecontact)]
triggerall = p2dist y >= -50 - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50*const(size.yscale)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 5 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 230
trigger2 = stateno = 200
trigger2 = (moveguarded)
var(52) = 230
ignorehitpause = 1

[State AI, Consider S.C]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 60
triggerall = p2dist y >= -60 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 250
trigger2 = stateno = 200
trigger2 = (moveguarded)
var(52) = 250
ignorehitpause = 1

[State AI, Consider S.Z]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = abs(p2bodydist x) <= 80
triggerall = p2dist y >= -80 - (enemynear,vel y*8)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale) || var(28)
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 88 || p2movetype = H
trigger1 = ctrl
trigger1 = prevstateno != 220
trigger2 = (stateno = 200 && anim = 200) || (stateno = 210 && anim = 211)
trigger2 = (movecontact)
var(52) = 220
ignorehitpause = 1

[State AI, J.L]
type = Varset
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = fvar(35)
;triggerall = p2bodydist x = [-40+(vel x*7)+(enemynear,vel x*7),32+(vel x*6)+(enemynear,vel x*7)]
triggerall = abs(p2bodydist x) <= 40+(vel x*8)+(enemynear,vel x*8)
triggerall = p2dist y >= -50 + (vel y*8) ; - (enemynear,vel y*6)
triggerall = (( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <=  -50 + (vel y*8)) || (vel y > 0 && random < 47)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
var(52) = 600 + ((random%6) * 10)
ignorehitpause = 1

[State AI, J.VL]
type = Varset
triggerall = var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = fvar(35)
triggerall = p2bodydist x = [-40+(vel x*8)+(enemynear,vel x*7),40+(vel x*8)+(enemynear,vel x*7)]
;triggerall = abs(p2bodydist x) <= 40+(vel x*5)+(enemynear,vel x*5)
triggerall = p2dist y >= -50 + (vel y*8) ; - (enemynear,vel y*6)
triggerall = (( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <=  -50 + (vel y*8)) || (vel y > 0 && random < 47)
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0 || p2movetype = A
triggerall = (stateno != [120,169])
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
trigger1 = ctrl
var(52) = 600 + ((random%3) * 10)
ignorehitpause = 1


[State AI, Consider a standin-for an air throw/air throwing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = fvar(35)
triggerall = roundstate = 2
triggerall = random < (15*(fvar(35)*fvar(35)))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 6
triggerall = abs(p2bodydist y) < 50
triggerall = statetype = A
triggerall = p2statetype = A
triggerall = prevstateno != [800,830]
triggerall = enemynear,prevstateno != [5120,5129]
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = 600 + ((random%6) * 10)
ignorehitpause = 1

[State AI, Consider Throwing]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = fvar(35)
triggerall = random < (15*(fvar(35)*fvar(35)))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 10
triggerall = statetype != A
triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = prevstateno != [800,830]
triggerall = prevstateno != 1350
triggerall = enemynear,prevstateno != [5120,5129]
triggerall = var(8) = 0
trigger1 = stateno != 40
trigger1 = ctrl
var(52) = ifelse(random<500,1200,ifelse(random<500,830,800))
ignorehitpause = 1

[State AI, Consider Dashing Straight]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.32*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 42)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),290])
triggerall = (p2dist y >= -80 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale) || var(28)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1000,1180]);(prevstateno != [1000,1030])
triggerall = !numtarget(1000)
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = anim != 20
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
var(52) = ifelse(p2bodydist x<=220,1000,ifelse(p2bodydist x<=260,1010,1020))
ignorehitpause = 1


[State AI, Consider Dashing Low]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.32*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=S,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 42)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),290])
triggerall = (p2dist y >= -20 - (enemynear,vel y*11))
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1000,1180]);(prevstateno != [1050,1080])
triggerall = !numtarget(1050)
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = anim != 20
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
var(52) = ifelse(p2bodydist x<=170,1050,ifelse(p2bodydist x<=240,1060,1070))
ignorehitpause = 1

[State AI, Consider Dashing Upper]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.32*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 42)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),290])
triggerall = (p2dist y >= -120 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale) || var(28)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1100,1130])
triggerall = !numtarget(1100)
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = anim != 20
trigger1 = var(9)
trigger1 = ctrl || (movecontact >= 2 && p2bodydist x >= 32)
var(52) = ifelse(p2bodydist x<=140,1100,ifelse(p2bodydist x<=240,1110,1120))
ignorehitpause = 1

[State AI, Consider Dashing Knockdown]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.32*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 42)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),290])
triggerall = (p2dist y >= -100 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1150,1180])
triggerall = !numtarget(1150)
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = anim != 20
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
var(52) = ifelse(p2bodydist x<=100,1150,ifelse(p2bodydist x<=200,1160,1170))
ignorehitpause = 1

[State AI, Consider Anti-Air]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.42*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 123)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype = A
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-10,-22),110-(8*(movecontact>=1))]
triggerall = p2dist y >= -235 - (enemynear,vel y*11)
triggerall = ((p2bodydist x) + p2bodydist y) = [-50,24] ; (p2bodydist x - p2bodydist y - (enemynear,vel y*7)) = [-50,24]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale) || var(28)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*10) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1200,1229])
triggerall = enemynear, anim != 5300
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2)
trigger1 = stateno != [200,250]
trigger1 = prevstateno != 1251
var(52) = ifelse(p2bodydist x<=70&&!movehit,1250,ifelse(p2bodydist x<=90&&!movehit,1260,1270))
ignorehitpause = 1

[State AI, Consider EX Dashing Straight]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.07*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 92)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),250])
triggerall = (p2dist y >= -80 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1000,1030])
triggerall = !numtarget(1000)
triggerall = enemynear, anim != 5300
triggerall = power >= 500
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
trigger2 = (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movehit
var(52) = 1030
ignorehitpause = 1


[State AI, Consider EX Dashing Low]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.07*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=S,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 92)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),250])
triggerall = (p2dist y >= -20 - (enemynear,vel y*11))
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1050,1080])
triggerall = !numtarget(1050)
triggerall = enemynear, anim != 5300
triggerall = power >= 500
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movehit
var(52) = 1080
ignorehitpause = 1

[State AI, Consider EX Dashing Upper]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.07*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 92)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),250])
triggerall = (p2dist y >= -120 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1100,1130])
triggerall = !numtarget(1100)
triggerall = enemynear, anim != 5300
triggerall = power >= 500
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
trigger2 = (stateno = [1000,1020]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movehit
var(52) = 1130
ignorehitpause = 1

[State AI, Consider EX Dashing Knockdown]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.07*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 92)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),250])
triggerall = (p2dist y >= -80 - (enemynear,vel y*11))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 11 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1150,1180])
triggerall = !numtarget(1150)
triggerall = enemynear, anim != 5300
triggerall = power >= 500
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2 && p2bodydist x >= 32)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || stateno = 1200
trigger2 = movehit
var(52) = 1180
ignorehitpause = 1

[State AI, Consider EX Anti-Air]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.07*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 123)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype = A
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-10,-22),130-(8*(movecontact>=1))]
triggerall = p2dist y >= -205 - (enemynear,vel y*7)
triggerall = ((p2bodydist x) + p2bodydist y) = [-50,24] ; (p2bodydist x - p2bodydist y - (enemynear,vel y*7)) = [-50,24]
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*10) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1250,1289])
triggerall = enemynear, anim != 5300
triggerall = power >= 500
trigger1 = stateno != 40
trigger1 = stateno != 20 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movehit >= 2)
trigger1 = prevstateno != 1251
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movehit
var(52) = 1280
ignorehitpause = 1

[State AI, Consider Sucker Punching]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+fvar(35)) && (var(52)!=[200,250]) && (var(52)!=[400,650]) )
triggerall = fvar(35)
triggerall = random < (0.19*(fvar(35)*fvar(35)*fvar(35))); * ifelse(movehit||p2statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 16)
triggerall = p2stateno != [5110,5130]
triggerall = (p2bodydist x = [ifelse(p2statetype!=A,-10,-22),140])
triggerall = (p2dist y >= -80 - (enemynear,vel y*27))
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -80*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 26 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = (prevstateno != [1200,1220])
triggerall = !numtarget(1200)
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || (movecontact >= 2)
var(52) = 1200
ignorehitpause = 1

[State AI, Consider Headbashing]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(fvar(35)*2)
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||(prevstateno=[120,159]),2,1)
triggerall = p2stateno != [5080,5130]
triggerall = p2stateno != [120,153]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-10,-22),30-(13*(movecontact>=1))]
triggerall = p2statetype != A
triggerall = p2statetype != L
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*12) + (enemynear, pos y) <= -17 ) || (p2stateno != [5030,5120])
triggerall = statetype != A
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (prevstateno != [1300,1329])
triggerall = enemynear, anim != 5300
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = var(9)
trigger1 = ctrl || movecontact || (animtime >= -3)
trigger1 = prevstateno != [1050,1080]
;trigger2 = ((stateno = [600,655]) && movehit) || (stateno = 658)
var(52) = 1300
ignorehitpause = 1
[State AI, Consider Keep On Bashing]
type = VarSet
triggerall = roundstate = 2
triggerall = fvar(35)
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
trigger1 = stateno = 1310
trigger1 = animelemtime(3) > 1
trigger1 = animelemtime(5) < 0
trigger1 = time < 10*fvar(35)
var(52) = 1310
ignorehitpause = 1

[State AI, Consider THE REBOOKS]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = fvar(35)
triggerall = random < (0.35*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1) + ((lifemax - life)/8)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 74)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x <= 140
triggerall = p2dist y >= -70*const(size.yscale) - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -63
;triggerall = p2statetype != A
triggerall = statetype != A
triggerall = power >= 1000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [3000,3002]
triggerall = p2stateno != [120,156]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5120])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movehit
trigger3 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger3 = movehit
trigger4 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger4 = movehit
trigger5 = stateno = 1030 || stateno = 1080 || stateno = 1130 || stateno = 1180 || stateno = 1280
trigger5 = time > 30
var(52) = 3000
ignorehitpause = 1

[State AI, Consider DOUBLE DAMAGE]
type = VarSet
triggerall = !var(28)
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = fvar(35)
triggerall = random < (0.16*(fvar(35)*fvar(35)*fvar(35))) * ifelse(moveguarded,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 54)
triggerall = p2bodydist x <= 42 || !movehit
;triggerall = p2statetype != A
triggerall = statetype != A
triggerall = power >= 2000
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [3050,3052]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5120])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movecontact
trigger3 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger3 = movehit
trigger4 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger4 = movehit
trigger5 = stateno = 1030 || stateno = 1080 || stateno = 1130 || stateno = 1180 || stateno = 1280
trigger5 = time > 30
var(52) = 3050
ignorehitpause = 1

[State AI, Consider CRUMBLE]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = fvar(35)
triggerall = random < (0.64*(fvar(35)*fvar(35)*fvar(35))) * ifelse(movehit||p2statetype=A,2,1) + ((lifemax - life)/8)
;triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 64)
triggerall = p2stateno != [5080,5130]
triggerall = p2statetype != L
triggerall = p2bodydist x <= 200
triggerall = p2dist y >= -70*const(size.yscale) - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -63
;triggerall = p2statetype != A
triggerall = statetype != A
triggerall = power >= 3000
triggerall = p2life <= ceil(512*fvar(13)) || p2life >= (enemynear,lifemax)
triggerall =(p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || (random < 80)
triggerall = prevstateno != [3000,3002]
triggerall = p2stateno != [120,156]
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*6) + (enemynear, pos y) <= -4 ) || (p2stateno != [5030,5120])
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 7-fvar(35))) || random < 10
triggerall = (enemynear,GetHitVar(hittime) >= 4 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
trigger1 = ctrl || stateno = 100
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 250
trigger2 = var(9)
trigger2 = movehit
trigger3 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger3 = movehit
trigger4 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger4 = movehit
trigger5 = stateno = 1030 || stateno = 1080 || stateno = 1130 || stateno = 1180 || stateno = 1280
trigger5 = time > 30
var(52) = 3200
ignorehitpause = 1


[State AI, Consider Straight super]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = fvar(35)
triggerall = p2bodydist x <= 100
triggerall = p2dist y >= -80*const(size.yscale) - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) > -87
trigger1 = stateno = [3000,3002]
trigger1 = var(0) != 0
var(52) = 3001
ignorehitpause = 1

[State AI, Consider Uppercuts super]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 140+fvar(35)
triggerall = fvar(35)
triggerall = p2bodydist x <= 80
triggerall = p2dist y >= -120*const(size.yscale) - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -87
trigger1 = stateno = [3000,3002]
trigger1 = var(0) != 1
var(52) = 3002
ignorehitpause = 1


[State AI, Consider Advancing]
type = VarSet
triggerall = !var(19)
triggerall = fvar(35)
triggerall = var(52) = 0 || random < 80+fvar(35)
triggerall = random < (33*fvar(35)) * ifelse(numhelper(3050),2,1)
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5130]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-fvar(35) || random < 10
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = ctrl
trigger1 = !moveguarded
var(52) = ifelse(random<200&&stateno!=100,ifelse(random<500,700,41),100)
ignorehitpause = 1

[State AI, Consider Countering/Guard Canceling]
type = VarSet
triggerall = !var(19)
triggerall = numenemy
triggerall = var(52) = 0 || random < 55+fvar(35)
triggerall = fvar(35)
triggerall = random < (0.05*(fvar(35)*fvar(35)*fvar(35))) + ifelse(p2life - life<0,0,(p2life - life)/4)
;triggerall = p2bodydist x = [-5,60]
;triggerall = p2dist y >= -50
triggerall = statetype != A
triggerall = power >= 1000
triggerall = power < 2000 || random < 32 || power >= 3000
triggerall = time >= 7-fvar(35) || random < 10
triggerall = (enemynear,time >= 14-(fvar(35)*2)) || random < 10
trigger1 = stateno = 150 || stateno = 152
var(52) = ifelse(random<500&&inguarddist,710,ifelse(random<500&&frontedgedist > 64,700,701))
ignorehitpause = 1

[State AI, Consider jumping in]
type = VarSet
triggerall = roundstate = 2
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+fvar(35) + (100*(stateno = 410))
triggerall = fvar(35)
triggerall = p2stateno != [5080,5130]
;triggerall = statetype != A || stateno = 410
triggerall = p2statetype = A && p2movetype = H
triggerall = (enemynear, pos y <= -45) || (stateno = 410)
trigger1 = ctrl || stateno = 100 || stateno = 40 || helper(10003),var(30)
trigger2 = stateno = 410
trigger2 = movecontact
var(52) = ifelse(p2bodydist x>=20,ifelse(p2bodydist x>=160,44,41),42)
ignorehitpause = 1

[State AI, Guard S]
type = ChangeState
triggerall = roundstate = 2
triggerall = stateno != 40
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = (fvar(35)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 14-(fvar(35)*2)))
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
;value = 130;ifelse(random<50&&(stateno!=[120,159])&&(prevstateno!=[700,705]),ifelse(random<123&&p2bodydist x<=55,ifelse(statetype=A,1120,1110),ifelse(random<500,700,705)),130)
value = ifelse(random<50&&(stateno!=[120,159])&&(prevstateno!=[700,710]),ifelse(random<500,700,701),130)

[State AI, Guard L]
type = ChangeState
triggerall = roundstate = 2
triggerall = stateno != 40
triggerall = random < (1*(fvar(35)*fvar(35)*fvar(35)))
triggerall = (fvar(35)) && (StateType != A) && (Ctrl) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = ((time >= 7-fvar(35)) && (enemynear,time >= 14-(fvar(35)*2)))
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
;value = 131;ifelse(random<50&&(stateno!=[120,159])&&(prevstateno!=[700,705]),ifelse(random<123&&p2bodydist x<=55,1100,ifelse(random<500,700,705)),131)
value = ifelse(random<50&&(stateno!=[120,159])&&(prevstateno!=[700,710]),ifelse(random<500,700,701),130)


; AI-related stuff ends here

;===========================================================================
;---------------------------------------------------------------------------

[State -1, GIGATON PUNCH]
type = ChangeState
value = 3200
triggerall = (fvar(35)<5 && command = "Gigaton") || var(52) = 3200
triggerall = power >= 3000
trigger1 = var(9)
trigger2 = (stateno = [1000,1030]) || (stateno = [1100,1130]) || (stateno = [1050,1080]) || (stateno = [1150,1180]) || stateno = 1200 || stateno = 1280
trigger2 = time
trigger3 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger3 = movecontact


[State -1, ROTATE MIRRORATION]
type = ChangeState
value = 3050
triggerall = (fvar(35)<5 && command = "hphk") || var(52) = 3050
triggerall = power >= 2000
triggerall = !var(28)
trigger1 = var(9)
trigger2 = (stateno = [1000,1030]) || (stateno = [1100,1130]) || (stateno = [1050,1080]) || (stateno = [1150,1180]) || stateno = 1200 || stateno = 1280
trigger2 = time
trigger3 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger3 = movecontact

[State -1, BUST YOU UP]
type = ChangeState
value = 3000
triggerall = (fvar(35)<5 && command = "CrazyBuffy") || var(52) = 3000
triggerall = power >= 1000
trigger1 = var(9)
trigger2 = (stateno = [1000,1030]) || (stateno = [1100,1130]) || (stateno = [1050,1080]) || (stateno = [1150,1180]) || stateno = 1200 || stateno = 1280
trigger2 = time
trigger3 = (stateno = 240 && anim = 240) || (stateno = 210 && anim = 210) || (stateno = 220 && anim = 221) || (stateno = 250 && anim = 251) || (stateno = 420) || (stateno = 450) || (stateno = 440)
trigger3 = movecontact

[State TAP buttons reset]
type = VarSet
trigger1 = time > 0
var(18) = 0
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holdx"
var(18) = var(18) + 1
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holdy"
var(18) = var(18) + 1
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holdz"
var(18) = var(18) + 1
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holda"
var(18) = var(18) + 1
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holdb"
var(18) = var(18) + 1
ignorehitpause = 1
[State TAP buttons add]
type = VarSet
trigger1 = command = "holdc"
var(18) = var(18) + 1
ignorehitpause = 1
[State -1, TAP PUNCH]
type = ChangeState
value = 1200
triggerall = var(9) ;Use combo condition (above)
trigger1 = var(52) = 1200
trigger2 = var(18) <= 1
trigger2 = var(19) >= 30
[State TAP buttons reset]
type = VarSet
trigger1 = stateno != 1200
trigger2 = stateno = 1200
trigger2 = time
var(19) = ifelse(var(18)>=2,var(19)+1,0)
ignorehitpause = 1

; Normal Special Moves

[State -1, Head Bomber]
type = ChangeState
value = 1300
;triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "360_p") || var(52) = 1300
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Upper EX]
type = ChangeState
value = 1130
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_ex") || var(52) = 1130
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movecontact

[State -1, Dash Upper L]
type = ChangeState
value = 1100
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_x") || var(52) = 1100
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Upper M]
type = ChangeState
value = 1110
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_y") || var(52) = 1110
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Upper H]
type = ChangeState
value = 1120
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_z") || var(52) = 1120
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Uppercut EX]
type = ChangeState
value = 1180
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_ax") || var(52) = 1180
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movecontact

[State -1, Dash Uppercut L]
type = ChangeState
value = 1150
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_a") || var(52) = 1150
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Uppercut M]
type = ChangeState
value = 1160
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_b") || var(52) = 1160
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Uppercut H]
type = ChangeState
value = 1170
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "upper_c") || var(52) = 1170
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight EX]
type = ChangeState
value = 1030
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_ex") || var(52) = 1030
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movecontact

[State -1, Dash Straight L]
type = ChangeState
value = 1000
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_x") || var(52) = 1000
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight M]
type = ChangeState
value = 1010
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_y") || var(52) = 1010
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight H]
type = ChangeState
value = 1020
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_z") || var(52) = 1020
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Low EX]
type = ChangeState
value = 1080
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_ax") || var(52) = 1080
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movecontact

[State -1, Dash Low L]
type = ChangeState
value = 1050
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_a") || var(52) = 1050
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Low M]
type = ChangeState
value = 1060
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_b") || var(52) = 1060
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Low H]
type = ChangeState
value = 1070
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "QC_c") || var(52) = 1070
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt EX]
type = ChangeState
value = 1280
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "CDU_ex") || var(52) = 1280
triggerall = power >= 500
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1020]) || (stateno = [1100,1120]) || (stateno = [1050,1070]) || (stateno = [1150,1170]) || stateno = 1200
trigger2 = movecontact

[State -1, Buff Headbutt L]
type = ChangeState
value = 1250
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "CDU_x") || var(52) = 1250
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt M]
type = ChangeState
value = 1260
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "CDU_y") || var(52) = 1260
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt H]
type = ChangeState
value = 1270
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "CDU_z") || var(52) = 1270
trigger1 = var(9) ;Use combo condition (above)

; V-Mode Special Moves

[State -1, Dash Upper L]
type = ChangeState
value = 1100
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vupper1",command = "vrupper1")) || var(52) = 1100
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Upper M]
type = ChangeState
value = 1110
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vupper2",command = "vrupper2")) || var(52) = 1110
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Upper H]
type = ChangeState
value = 1120
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vupper3",command = "vrupper3")) || var(52) = 1120
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight L]
type = ChangeState
value = 1000
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vQCF1",command = "vQCB1")) || var(52) = 1000
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight M]
type = ChangeState
value = 1010
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vQCF2",command = "vQCB2")) || var(52) = 1010
trigger1 = var(9) ;Use combo condition (above)

[State -1, Dash Straight H]
type = ChangeState
value = 1020
triggerall = var(28)
triggerall = (fvar(35)<5 && ifelse((anim!=[5,6]),command = "vQCF3",command = "vQCB3")) || var(52) = 1020
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt L]
type = ChangeState
value = 1250
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "vCDU1") || var(52) = 1250
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt M]
type = ChangeState
value = 1260
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "vCDU2") || var(52) = 1260
trigger1 = var(9) ;Use combo condition (above)

[State -1, Buff Headbutt H]
type = ChangeState
value = 1270
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "vCDU3") || var(52) = 1270
trigger1 = var(9) ;Use combo condition (above)


;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = !var(19)
trigger1 = (command = "FF") || (var(52) = 100)
trigger1 = statetype = S || stateno = 105
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = !var(19)
trigger1 = (command = "BB") || (var(52) = 105)
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Dodge
;p`
[State -1, Stand Dodge]
type = ChangeState
value = 700
triggerall = (fvar(35)<5 && (command = "lplk" && command != "holdback")) || var(52) = 700
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [150,156]
trigger2 = power >= 1000
trigger3 = var(9)
trigger3 = power >= 1000

[State -1, Stand Dodge]
type = ChangeState
value = 701
triggerall = (fvar(35)<5 && (command = "lplk" && command = "holdback")) || var(52) = 701
triggerall = statetype != A
trigger1 = ctrl
trigger2 = stateno = [150,156]
trigger2 = power >= 1000
trigger3 = var(9)
trigger3 = power >= 1000

[State -1, Guard Counter Attack]
type = ChangeState
value = 710
triggerall = (fvar(35)<5 && command = "holdfwd" &&  command = "tupac" ) || var(52) = 710
triggerall = statetype != A
trigger1 = stateno = [150,156]
trigger1 = power >= 1000


;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = ((command = "y" || command = "z") && (command = "holdfwd" || command = "holdback")) || var(52) = 800
triggerall = statetype != A
triggerall = ctrl
triggerall = stateno != 100
triggerall = var(8) <= 0
trigger1 = abs(p2bodydist X) < 15
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H


[State -1, Kung Fu Throw]
type = ChangeState
value = ifelse(var(28),800,830)
triggerall = ((command = "b" || command = "c") && (command = "holdfwd" || command = "holdback")) || var(52) = 830
triggerall = statetype != A
triggerall = ctrl
triggerall = stateno != 100
triggerall = var(8) <= 0
trigger1 = abs(p2bodydist X) < 15
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;---------------------------------------------------------------------------
; Normal Stand Attacks
[State -1, Stand Jab]
type = ChangeState
value = 200
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "x" && command != "holddown")) || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Strong]
type = ChangeState
value = 210
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "y" && command != "holddown")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 240) || (stateno = 210 && anim = 211) || (stateno = 250 && anim = 251) || stateno = 400
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Fierce]
type = ChangeState
value = 220
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "z" && command != "holddown")) || var(52) = 220
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 210 && anim = 211) || stateno = 400
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Short]
type = ChangeState
value = 230
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "a" && command != "holddown")) || var(52) = 230
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Forward]
type = ChangeState
value = 240
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "b" && command != "holddown")) || var(52) = 240
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Roundhouse]
type = ChangeState
value = 250
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "c" && command != "holddown")) || var(52) = 250
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 210 && anim = 211) || stateno = 400
trigger2 = (animtime >= -9 || movecontact)


[State -1, Taunt]
type = ChangeState
value = 195
triggerall = (command = "start") || var(52) = 195; || (var(58) = -2 && winko && !var(48))
triggerall = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl


;---------------------------------------------------------------------------
;Crouching Attacks
[State -1, Crouch Jab]
type = ChangeState
value = 400
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "x" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Strong]
type = ChangeState
value = 410
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "y" && command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Fierce]
type = ChangeState
value = 420
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "z" && command = "holddown")) || var(52) = 420
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || (stateno = 240 && anim = 241)
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Short]
type = ChangeState
value = 430
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "a" && command = "holddown")) || var(52) = 430
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 400
;trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Forward]
type = ChangeState
value = 440
triggerall = !var(28)
triggerall = (fvar(35)<5 && (command = "b" && command = "holddown")) || var(52) = 440
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Roundhouse]
type = ChangeState
value = 450
triggerall = (fvar(35)<5 && (command = "c" && command = "holddown")) || var(52) = 450
triggerall = !var(28)
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

;---------------------------------------------------------------------------
;Jump
[State -1, Jump Jab]
type = ChangeState
value = 600
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "x") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Strong]
type = ChangeState
value = 610
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "y") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Fierce]
type = ChangeState
value = 620
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "z") || var(52) = 620
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Short]
type = ChangeState
value = 630
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "a") || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Forward]
type = ChangeState
value = 640
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "b") || var(52) = 640
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Roundhouse]
type = ChangeState
value = 650
triggerall = !var(28)
triggerall = (fvar(35)<5 && command = "c") || var(52) = 650
trigger1 = statetype = A
trigger1 = ctrl


;---------------------------------------------------------------------------
; V-Mode Stand Attacks
[State -1, Stand Jab]
type = ChangeState
value = 200
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v1" && command != "holddown")) || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Strong]
type = ChangeState
value = 210
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v2" && command != "holddown")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 240) || (stateno = 210 && anim = 211) || (stateno = 250 && anim = 251)
trigger2 = (animtime >= -9 || movecontact)

[State -1, Stand Fierce]
type = ChangeState
value = 220
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v3" && command != "holddown")) || var(52) = 220
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || (stateno = 210 && anim = 211)
trigger2 = (animtime >= -9 || movecontact)


;---------------------------------------------------------------------------
;Crouching Attacks
[State -1, Crouch Jab]
type = ChangeState
value = 400
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v1" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Strong]
type = ChangeState
value = 410
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v2" && command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 400 || stateno = 430
trigger2 = (animtime >= -9 || movecontact)

[State -1, Crouch Fierce]
type = ChangeState
value = 420
triggerall = var(28)
triggerall = (fvar(35)<5 && (command = "v3" && command = "holddown")) || var(52) = 420
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || (stateno = 240 && anim = 241)
trigger2 = (animtime >= -9 || movecontact)

;---------------------------------------------------------------------------
;Jump
[State -1, Jump Jab]
type = ChangeState
value = 600
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "v1") || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Strong]
type = ChangeState
value = 610
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "v2") || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl

[State -1, Jump Fierce]
type = ChangeState
value = 620
triggerall = var(28)
triggerall = (fvar(35)<5 && command = "v3") || var(52) = 620
trigger1 = statetype = A
trigger1 = ctrl


[State -1, Air combo lol]
type = ChangeState
value = ifelse(statetype=A,45,40)
triggerall = (command = "holdup") || var(52) = [40,45]
trigger1 = fvar(35)
trigger1 = stateno != 40
trigger1 = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 100
;trigger3 = stateno = 410
;trigger3 = movehit

